@@ -82,7 +82,9 @@ def workspace_other_root_path(tmpdir):
 @pytest.fixture
 def config(workspace):  # pylint: disable=redefined-outer-name
     """Return a config object."""
-    return Config(workspace.root_uri, {}, 0, {})
+    cfg = Config(workspace.root_uri, {}, 0, {})
+    cfg._plugin_settings = {'plugins': {'pylint': {'enabled': False, 'args': [], 'executable': None}}}
+    return cfg
 
 
 @pytest.fixture
